=======
Credits
=======

Development Lead
----------------

* Jochen Wersdörfer <jochen-wagtailsrcst@wersdoerfer.de>
* Johannes Spielmann <j@spielmannsolutions.com>

Contributors
------------

None yet. Why not be the first?
